@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# This file is part of the Wapiti project (http://wapiti.sourceforge.net)
-# Copyright (C) 2017-2019 Nicolas Surribas
+# This file is part of the Wapiti project (http://wapiti.sourceforge.io)
+# Copyright (C) 2017-2020 Nicolas Surribas
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,4 +17,4 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-parser_name = "lxml"
+parser_name = "html.parser"
