@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# This file is part of the Wapiti project (http://wapiti.sourceforge.net)
-# Copyright (C) 2008-2019 Nicolas Surribas
+# This file is part of the Wapiti project (http://wapiti.sourceforge.io)
+# Copyright (C) 2008-2020 Nicolas Surribas
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ from requests.exceptions import Timeout, ReadTimeout
 from wapitiCore.attack.attack import Attack, PayloadType, Mutator
 from wapitiCore.language.vulnerability import Vulnerability, Anomaly, _
 from wapitiCore.net import web
-from wapitiCore.net.xss_utils import generate_payloads, valid_xss_content_type
+from wapitiCore.net.xss_utils import generate_payloads, valid_xss_content_type, find_non_exec_parent, has_csp
 
 
 class mod_permanentxss(Attack):
@@ -65,8 +65,9 @@ class mod_permanentxss(Attack):
         get_resources = self.persister.get_links(attack_module=self.name) if self.do_get else []
 
         for original_request in get_resources:
-            if not valid_xss_content_type(original_request):
+            if not valid_xss_content_type(original_request) or original_request.status in (301, 302, 303):
                 # If that content-type can't be interpreted as HTML by browsers then it is useless
+                # Same goes for redirections
                 continue
 
             url = original_request.url
@@ -159,6 +160,9 @@ class mod_permanentxss(Attack):
                                             input_request.path
                                         )
 
+                                    if has_csp(response):
+                                        description += ".\n" + _("Warning: Content-Security-Policy is present!")
+
                                     self.add_vuln(
                                         request_id=original_request.path_id,
                                         category=Vulnerability.XSS,
@@ -180,6 +184,10 @@ class mod_permanentxss(Attack):
                                         original_request.path,
                                         parameter
                                     )
+
+                                    if has_csp(response):
+                                        self.log_red(_("Warning: Content-Security-Policy is present!"))
+
                                     self.log_red(Vulnerability.MSG_EVIL_REQUEST)
                                     self.log_red(evil_request.http_repr())
                                     self.log_red("---")
@@ -261,7 +269,11 @@ class mod_permanentxss(Attack):
                 except ReadTimeout:
                     continue
 
-                if self.check_payload(response, xss_flags, taint):
+                if (
+                        response.status not in (301, 302, 303) and
+                        valid_xss_content_type(evil_request) and
+                        self.check_payload(response, xss_flags, taint)
+                ):
 
                     if page == output_request.path:
                         description = _(
@@ -277,6 +289,9 @@ class mod_permanentxss(Attack):
                             page
                         )
 
+                    if has_csp(response):
+                        description += ".\n" + _("Warning: Content-Security-Policy is present!")
+
                     self.add_vuln(
                         request_id=injection_request.path_id,
                         category=Vulnerability.XSS,
@@ -299,6 +314,10 @@ class mod_permanentxss(Attack):
                         output_url,
                         xss_param
                     )
+
+                    if has_csp(response):
+                        self.log_red(_("Warning: Content-Security-Policy is present!"))
+
                     self.log_red(Vulnerability.MSG_EVIL_REQUEST)
                     self.log_red(evil_request.http_repr())
                     self.log_red("---")
@@ -366,25 +385,47 @@ class mod_permanentxss(Attack):
 
         for section in config_reader.sections():
             if section in flags:
-                value = config_reader[section]["value"].replace("__XSS__", taint)
+                expected_value = config_reader[section]["value"].replace("__XSS__", taint)
                 attribute = config_reader[section]["attribute"]
                 case_sensitive = config_reader[section].getboolean("case_sensitive")
+                match_type = config_reader[section].get("match_type", "exact")
 
                 for tag in response.soup.find_all(config_reader[section]["tag"]):
+                    if find_non_exec_parent(tag):
+                        continue
+
                     if attribute == "string" and tag.string:
                         if case_sensitive:
-                            if value in tag.string:
+                            if expected_value in tag.string:
                                 return True
                         else:
-                            if value.lower() in tag.string.lower():
+                            if expected_value.lower() in tag.string.lower():
+                                return True
+                    elif attribute == "full_string" and tag.string:
+                        if case_sensitive:
+                            if match_type == "exact" and expected_value == tag.string.strip():
+                                return True
+                            elif match_type == "starts_with" and tag.string.strip().startswith(expected_value):
+                                return True
+                        else:
+                            if match_type == "exact" and expected_value.lower() == tag.string.strip().lower():
+                                return True
+                            elif match_type == "starts_with" and \
+                                    tag.string.strip().lower().startswith(expected_value.lower()):
                                 return True
                     else:
+                        # Found attribute specified in .ini file in attributes of the HTML tag
                         if attribute in tag.attrs:
                             if case_sensitive:
-                                if value in tag[attribute]:
+                                if match_type == "exact" and tag[attribute] == expected_value:
+                                    return True
+                                elif match_type == "starts_with" and tag[attribute].startswith(expected_value):
                                     return True
                             else:
-                                if value.lower() in tag[attribute].lower():
+                                if match_type == "exact" and tag[attribute].lower() == expected_value.lower():
+                                    return True
+                                elif match_type == "starts_with" and \
+                                        expected_value.lower().startswith(tag[attribute].lower()):
                                     return True
                 break
 
